Deletes all locally cached UK housing data files. The next call to any data function will re-download fresh data.
See also
Other configuration:
ukh_cache_info(),
ukh_epc_set_key()
Deletes all locally cached UK housing data files. The next call to any data function will re-download fresh data.
Other configuration:
ukh_cache_info(),
ukh_epc_set_key()