Skip to contents

Uses the Land Registry linked data address lookup to find all transactions at a given postcode. Faster than downloading the yearly bulk file when you only want a single postcode.

Usage

ukh_ppd_address(postcode)

Arguments

postcode

Character. Full UK postcode (e.g. "SW1A 1AA").

Value

A data frame of transactions at addresses matching the postcode.

Examples

# \donttest{
op <- options(ukhousing.cache_dir = tempdir())
tx <- ukh_ppd_address("SW1A 1AA")
head(tx)
#> data frame with 0 columns and 0 rows
options(op)
# }