Skip to contents

Fetches the full metadata for one transaction from the Land Registry linked data service by its transaction unique identifier.

Usage

ukh_ppd_transaction(id)

Arguments

id

Character. A transaction unique identifier (GUID, with or without curly braces).

Value

A one-row data frame with the transaction fields, or an empty data frame if the transaction is not found.

Examples

# \donttest{
op <- options(ukhousing.cache_dir = tempdir())
tx <- ukh_ppd_transaction("{A4C5B0C6-4D5D-47E2-E053-6C04A8C07E7C}")
tx
#> data frame with 0 columns and 0 rows
options(op)
# }