Returns all available fields and any improvement recommendations for one Energy Performance Certificate identified by its LMK key.
Usage
ukh_epc_certificate(lmk_key, type = c("domestic", "non-domestic", "display"))Arguments
- lmk_key
Character. The certificate's LMK key (found in the
lmk_keycolumn ofukh_epc_search()results).- type
Character. Register:
"domestic"(default),"non-domestic", or"display".
Value
A list with two elements:
- certificate
A one-row data frame with all certificate fields.
- recommendations
A data frame of improvement recommendations (may be empty).
See also
Other energy performance certificates:
ukh_epc_bulk(),
ukh_epc_recommendations_summary(),
ukh_epc_search(),
ukh_epc_summary()