Fetches the full metadata for one transaction from the Land Registry linked data service by its transaction unique identifier.
Value
A one-row data frame with the transaction fields, or an empty data frame if the transaction is not found.
See also
Other price paid data:
ukh_ppd(),
ukh_ppd_address(),
ukh_ppd_bulk(),
ukh_ppd_summary(),
ukh_ppd_years()